{% extends 'buybacks2/page.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}

{% block body %}
    <form class="form" action="{% url 'buybacks2:notification_edit' notification_pk=notification.id %}?mine={{ mine }}" method="POST">
        {% csrf_token %}
        {{ form|bootstrap }}

        <div style="text-align: center; margin-top: 20px;">
            <p class="text-muted">
                Total Contract Value:
                <span class="text-primary" id="total">{{ notification.total|floatformat:"0g" }}</span>
                ISK
            </p>
        </div>

        <button type="submit" class="btn btn-primary">{% trans "Edit" %}</button>
    </form>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
