EVE_CATEGORY_ID_MATERIAL = 4
EVE_CATEGORY_ID_SHIP = 6
EVE_CATEGORY_ID_MODULE = 7
EVE_CATEGORY_ID_CHARGE = 8
EVE_CATEGORY_ID_COMMODITY = 17
EVE_CATEGORY_ID_DRONE = 18
EVE_CATEGORY_ID_ASTEROID = 25
EVE_CATEGORY_ID_PLANETARY_COMMODITY = 43
EVE_CATEGORY_ID_FIGHTER = 87

EVE_GROUP_ID_HARVESTABLE_CLOUD = 711
