{% extends 'buybacks2/base.html' %}
{% load i18n %}
{% load humanize %}
{% load dict %}
{% load number %}
{% load date %}

{% block details %}
    <div class="table-responsive">
        <table style="width: 100%; margin: auto;" class="table table-striped table-condensed">
            <thead>
            <tr>
                <th style="width: 15%;">{% trans "Date" %}</th>
                {% if not mine %}
                    <th style="width: 15%;">{% trans "User" %}</th>
                {% endif %}
                <th style="width: 35%;">{% trans "Buyback Program" %}</th>
                <th style="width: 15%;">{% trans "Corporation" %}</th>
                <th style="width: 20%; text-align: center;">{% trans "Total" %}</th>
            </tr>
            </thead>
            <tbody>
            {% for contract in contracts %}
                <tr>
                    <td>{{ contract.date|time }}</td>
                    {% if not mine %}
                        <td>{{ contract.character.character.character_name }}</td>
                    {% endif %}
                    <td>{{ contract.program.name }}</td>
                    <td>{{ contract.program.corporation }}</td>
                    <td style="text-align: right;">{{ contract.total|floatformat:"0g" }} ISK</td>
                </tr>
            {% endfor %}
            </tbody>
        </table>
    </div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
