{% extends 'buybacks2/base.html' %}

{% block details %}
    <div class="panel panel-primary">
        <div class="panel-heading">
            <h3 class="panel-title">{{ corporation.corporation_name }} ({{ corporation.corporation_ticker }})</h3>
        </div>
        <div class="panel-body" style="min-height: 100px;">
            {% block body %}{% endblock %}
        </div>
    </div>
{% endblock %}
